@@ -655,13 +655,22 @@ def execute_strategy_multi_asset(
                     except:
                         pass
 
-                    float_number_to_be_bought = round(
-                        (
-                            float_budget_in_usd
-                            - dict_constraints['float_minimum_cash']
-                        ) / float_price,
-                        dict_general_settings['int_rounding_decimal_places_for_security_quantities']
-                    )
+                    if dict_strategy_hyperparameters['boolean_percentage_in_signal_table']:
+                        float_number_to_be_bought = round(
+                            (
+                                (df_trading_journal['Portfolio value'] * row['percentage_to_be_bought']) - dict_constraints['float_minimum_cash']
+                            ) / float_price,
+                            dict_general_settings['int_rounding_decimal_places_for_security_quantities']
+                        )
+                        print('BUY CORRECT')
+                    else:
+                        float_number_to_be_bought = round(
+                            (
+                                float_budget_in_usd
+                                - dict_constraints['float_minimum_cash']
+                            ) / float_price,
+                            dict_general_settings['int_rounding_decimal_places_for_security_quantities']
+                        )
 
                 else:
                     float_number_to_be_bought = None
@@ -684,15 +693,24 @@ def execute_strategy_multi_asset(
                         )
                     ) is None
                 ):
-                    float_number_to_be_bought = (-1) * (
-                        find_dataframe_value_with_keywords(
-                            df_trading_journal,
-                            search_term_1=crypto_key,
-                            search_column_name_1='Asset',
-                            output_column_name='Exposure (number)',
-                            first_last_or_all_elements='Last'
+                    if dict_strategy_hyperparameters['boolean_percentage_in_signal_table']:
+                        float_number_to_be_bought = round(
+                            (
+                                (df_trading_journal['Portfolio value'] * row['percentage_to_be_bought'])
+                            ) / float_price,
+                            dict_general_settings['int_rounding_decimal_places_for_security_quantities']
+                        )
+                        print('SELL CORRECT')
+                    else:
+                        float_number_to_be_bought = (-1) * (
+                            find_dataframe_value_with_keywords(
+                                df_trading_journal,
+                                search_term_1=crypto_key,
+                                search_column_name_1='Asset',
+                                output_column_name='Exposure (number)',
+                                first_last_or_all_elements='Last'
+                            )
                         )
-                    )
 
                 else:
                     float_number_to_be_bought = None
